"""
Python library for the uh.cx link shortener.

http://uh.cx/
"""

import json

import requests


class Manager:
    _url = 'http://uh.cx/api/create'

    class Link:
        url_original = ''
        url_redirect = ''
        url_preview = ''
        qr_redirect = ''
        qr_preview = ''

    class InvalidResponseException(Exception):
        pass

    class CouldNotCreateLinkException(Exception):
        pass

    class ResponseValidator:
        _keys = ['QrDirect', 'QrPreview', 'UrlDirect', 'UrlOriginal', 'UrlPreview']

        @staticmethod
        def check(response):
            for key in Manager.ResponseValidator._keys:
                if key not in response:
                    return False

            return True

    @staticmethod
    def create(url):
        data = json.dumps({'url': url})
        response = requests.post(Manager._url, data)

        if response.status_code != 200:
            raise Manager.CouldNotCreateLinkException()

        response_data = response.json()

        if not Manager.ResponseValidator.check(response_data):
            raise Manager.InvalidResponseException()

        link = Manager.Link()
        link.qr_preview = response_data['QrPreview']
        link.qr_redirect = response_data['QrDirect']
        link.url_original = response_data['UrlOriginal']
        link.url_preview = response_data['UrlPreview']
        link.url_redirect = response_data['UrlDirect']

        return link



# -*- coding: utf-8 -*-
"""
uh.cx API interface

http://uh.cx/
"""


class CouldNotConnectException(Exception):
    pass


class InvalidResponseException(Exception):
    pass


class CouldNotDecodeJsonException(Exception):
    pass


"""
Python library for the uh.cx link shortener.

http://uh.cx/
"""

from distutils.core import setup

from setuptools import find_packages


setup(
    name='uhcx',
    version='0.2.1',
    author='J. Boehm',
    author_email='jb@uh.cx',
    packages=find_packages(exclude=['contrib', 'docs', 'tests*']),
    url='http://uh.cx/',
    license='MIT',
    description='Library for the uh.cx link shortener.',
    install_requires=['requests'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Internet :: WWW/HTTP',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
    ],
)



# -*- coding: utf-8 -*-
"""
uh.cx API interface

http://uh.cx/
"""

import unittest

import uhcx


class Tests(unittest.TestCase):
    def testCreateLink(self):
        url = 'http://www.google.de/'
        link = uhcx.Manager.create(url)

        self.assertIsNotNone(link)
        self.assertEqual(url, link.url_original)

    def testCreateInvalidLink(self):
        self.assertRaises(uhcx.Manager.CouldNotCreateLinkException, uhcx.Manager.create, 'asd')


def main():
    unittest.main()


if __name__ == '__main__':
    main()
